==> CGFBApp-1.0.1.tar.gz: CGFBApp/action.defaultadmin.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFBApp (c) 2010 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  A toolbox of conveniences to build facebook integration into a website
#  for CMS modules and website designers.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

echo $this->StartTabHeaders();
if( $this->CheckPermission('Modify Site Preferences') )
  {
    echo $this->SetTabHeader('fbsettings',$this->Lang('facebook_settings'));
  }
if( $this->CheckPermission('Modify Templates') )
  {
    echo $this->SetTabHeader('fbinitsync_tpl',$this->Lang('fbinitsync_template'));
    echo $this->SetTabHeader('fbinitasync_tpl',$this->Lang('fbinitasync_template'));
    echo $this->SetTabHeader('invite_tab',$this->Lang('invite_template'));
    echo $this->SetTabHeader('dflt_templates',$this->Lang('dflt_templates'));
  }
echo $this->EndTabHeaders();


echo $this->StartTabContent();
if( $this->CheckPermission('Modify Site Preferences') )
  {
    echo $this->StartTab('fbsettings',$params);
    include(dirname(__FILE__).'/function.admin_fbsettings_tab.php');
    echo $this->EndTab();
  }
if( $this->CheckPermission('Modify Templates') )
  {
    echo $this->StartTab('fbinitsync_tpl',$params);
    include(dirname(__FILE__).'/function.admin_fbinitsync_tab.php');
    echo $this->EndTab();

    echo $this->StartTab('fbinitasync_tpl',$params);
    include(dirname(__FILE__).'/function.admin_fbinitasync_tab.php');
    echo $this->EndTab();

    echo $this->StartTab('invite_tab',$params);
    include(dirname(__FILE__).'/function.admin_invite_tab.php');
    echo $this->EndTab();

    echo $this->StartTab('dflt_templates',$params);
    include(dirname(__FILE__).'/function.admin_dflttemplates_tab.php');
    echo $this->EndTab();
  }

echo $this->EndTabContent();

#
# EOF
#
?>

==> CGFBApp-1.0.9.tar.gz: CGFBApp/action.defaultadmin.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFBApp (c) 2010-2013 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  A toolbox of conveniences to build facebook integration into a website
#  for CMS modules and website designers.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

echo $this->StartTabHeaders();
if( $this->CheckPermission('Modify Site Preferences') )
  {
    echo $this->SetTabHeader('fbsettings',$this->Lang('facebook_settings'));
    echo $this->SetTabHeader('gensettings',$this->Lang('generic_settings'));
//     echo $this->SetTabHeader('sendpost',$this->Lang('sendpost_tab'));
  }
if( $this->CheckPermission('Modify Templates') )
  {
    echo $this->SetTabHeader('fbinitsync_tpl',$this->Lang('fbinitsync_template'));
    echo $this->SetTabHeader('fbinitasync_tpl',$this->Lang('fbinitasync_template'));
    echo $this->SetTabHeader('invite_tab',$this->Lang('invite_template'));
    if( $this->GetPreference('dofeuauth') ) {
      echo $this->SetTabHeader('login_tab',$this->Lang('login_templates'));
      echo $this->SetTabHeader('logout_tab',$this->Lang('logout_templates'));
    }
    echo $this->SetTabHeader('dflt_templates',$this->Lang('dflt_templates'));
  }
echo $this->EndTabHeaders();


echo $this->StartTabContent();
if( $this->CheckPermission('Modify Site Preferences') ) {
  echo $this->StartTab('fbsettings',$params);
  include(dirname(__FILE__).'/function.admin_fbsettings_tab.php');
  echo $this->EndTab();

  echo $this->StartTab('gensettings',$params);
  include(dirname(__FILE__).'/function.admin_gensettings_tab.php');
  echo $this->EndTab();

//   echo $this->StartTab('sendpost',$params);
//   include(dirname(__FILE__).'/function.admin_sendpost_tab.php');
//   echo $this->EndTab();
}
if( $this->CheckPermission('Modify Templates') )
  {
    echo $this->StartTab('fbinitsync_tpl',$params);
    include(dirname(__FILE__).'/function.admin_fbinitsync_tab.php');
    echo $this->EndTab();

    echo $this->StartTab('fbinitasync_tpl',$params);
    include(dirname(__FILE__).'/function.admin_fbinitasync_tab.php');
    echo $this->EndTab();

    echo $this->StartTab('invite_tab',$params);
    include(dirname(__FILE__).'/function.admin_invite_tab.php');
    echo $this->EndTab();

    if( $this->GetPreference('dofeuauth') ) {
      echo $this->StartTab('login_tab',$params);
      include(dirname(__FILE__).'/function.admin_login_tab.php');
      echo $this->EndTab();

      echo $this->StartTab('logout_tab',$params);
      include(dirname(__FILE__).'/function.admin_logout_tab.php');
      echo $this->EndTab();
    }

    echo $this->StartTab('dflt_templates',$params);
    include(dirname(__FILE__).'/function.admin_dflttemplates_tab.php');
    echo $this->EndTab();
  }

echo $this->EndTabContent();

#
# EOF
#
?>
